@@ -546,15 +546,19 @@ class TestCscMatrixScipyComparison:
         return n
 
     # dot
-    @testing.numpy_cupy_allclose(sp_name='sp')
-    def test_dot_scalar(self, xp, sp):
-        m = self.make(xp, sp, self.dtype)
-        return m.dot(2.0)
+    @testing.with_requires('scipy>=1.8.0rc1')
+    def test_dot_scalar(self):
+        for xp, sp in ((numpy, scipy.sparse), (cupy, sparse)):
+            m = self.make(xp, sp, self.dtype)
+            with pytest.raises(ValueError):
+                m.dot(2.0)
 
-    @testing.numpy_cupy_allclose(sp_name='sp')
-    def test_dot_numpy_scalar(self, xp, sp):
-        m = self.make(xp, sp, self.dtype)
-        return m.dot(numpy.dtype(self.dtype).type(2.0))
+    @testing.with_requires('scipy>=1.8.0rc1')
+    def test_dot_numpy_scalar(self):
+        for xp, sp in ((numpy, scipy.sparse), (cupy, sparse)):
+            m = self.make(xp, sp, self.dtype)
+            with pytest.raises(ValueError):
+                m.dot(numpy.dtype(self.dtype).type(2.0))
 
     @pytest.mark.skipif(runtime.is_hip and driver.get_build_version() < 400,
                         reason='no working implementation')
@@ -589,11 +593,13 @@ class TestCscMatrixScipyComparison:
         x = _make3(xp, sp, self.dtype).tocoo()
         return m.dot(x)
 
-    @testing.numpy_cupy_allclose(sp_name='sp')
-    def test_dot_zero_dim(self, xp, sp):
-        m = self.make(xp, sp, self.dtype)
-        x = xp.array(2, dtype=self.dtype)
-        return m.dot(x)
+    @testing.with_requires('scipy>=1.8.0rc1')
+    def test_dot_zero_dim(self):
+        for xp, sp in ((numpy, scipy.sparse), (cupy, sparse)):
+            m = self.make(xp, sp, self.dtype)
+            x = xp.array(2, dtype=self.dtype)
+            with pytest.raises(ValueError):
+                m.dot(x)
 
     @testing.numpy_cupy_allclose(sp_name='sp')
     def test_dot_dense_vector(self, xp, sp):
@@ -893,6 +899,11 @@ class TestCscMatrixScipyComparison:
                 x * m
 
     def test_rmul_unsupported(self):
+        if (
+            numpy.lib.NumpyVersion(scipy.__version__) >= '1.8.0rc1' and
+            self.make_method not in ['_make_empty', '_make_shape']
+        ):
+            pytest.xfail('See scipy/15210')
         for xp, sp in ((numpy, scipy.sparse), (cupy, sparse)):
             m = self.make(xp, sp, self.dtype)
             # TODO(unno): When a sparse matrix has no element, scipy.sparse
